==> haskell-charset-0.3.12-27-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-charset.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 charset
version:              0.3.12
visibility:           public
id:                   charset-0.3.12-D5cirNAvuYVC1VCEaOda6I
key:                  charset-0.3.12-D5cirNAvuYVC1VCEaOda6I
license:              BSD-3-Clause
copyright:            (c) Edward Kmett 2010-2012
maintainer:           ekmett@gmail.com
author:               Edward Kmett
stability:            Experimental
homepage:             http://github.com/ekmett/charset
synopsis:
    Fast unicode character sets based on complemented PATRICIA tries

description:
    Fast unicode character sets based on complemented PATRICIA tries.

category:             Data
abi:                  7138d100f08464909154895403d823c6
exposed:              True
exposed-modules:
    Data.CharSet Data.CharSet.ByteSet Data.CharSet.Common
    Data.CharSet.Posix Data.CharSet.Posix.Ascii
    Data.CharSet.Posix.Unicode Data.CharSet.Unicode
    Data.CharSet.Unicode.Block Data.CharSet.Unicode.Category

import-dirs:          /usr/lib/ghc-9.4.8/site-local/charset-0.3.12
library-dirs:         /usr/lib/ghc-9.4.8/site-local/charset-0.3.12
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/charset-0.3.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-charset
hs-libraries:         HScharset-0.3.12-D5cirNAvuYVC1VCEaOda6I
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    unordered-containers-0.2.20-DP4QHaCUkq0wtUis18g4W

haddock-interfaces:   /usr/share/doc/haskell-charset/html/charset.haddock
haddock-html:         /usr/share/doc/haskell-charset/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-charset-0.3.12-28-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-charset.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 charset
version:              0.3.12
visibility:           public
id:                   charset-0.3.12-1TQIy3e17Xo2DgzRg8ZmJm
key:                  charset-0.3.12-1TQIy3e17Xo2DgzRg8ZmJm
license:              BSD-3-Clause
copyright:            (c) Edward Kmett 2010-2012
maintainer:           ekmett@gmail.com
author:               Edward Kmett
stability:            Experimental
homepage:             http://github.com/ekmett/charset
synopsis:
    Fast unicode character sets based on complemented PATRICIA tries

description:
    Fast unicode character sets based on complemented PATRICIA tries.

category:             Data
abi:                  b4a9afb13e11842e7d284139a0e3267d
exposed:              True
exposed-modules:
    Data.CharSet Data.CharSet.ByteSet Data.CharSet.Common
    Data.CharSet.Posix Data.CharSet.Posix.Ascii
    Data.CharSet.Posix.Unicode Data.CharSet.Unicode
    Data.CharSet.Unicode.Block Data.CharSet.Unicode.Category

import-dirs:          /usr/lib/ghc-9.4.8/site-local/charset-0.3.12
library-dirs:         /usr/lib/ghc-9.4.8/site-local/charset-0.3.12
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/charset-0.3.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-charset
hs-libraries:         HScharset-0.3.12-1TQIy3e17Xo2DgzRg8ZmJm
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    unordered-containers-0.2.20-8pr2L2RDRM8Dqz21gIQp5G

haddock-interfaces:   /usr/share/doc/haskell-charset/html/charset.haddock
haddock-html:         /usr/share/doc/haskell-charset/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
